@@ -1,7 +1,7 @@
 """Tinychain `State`\s, such as `Map`, `Tuple`, and `Op`."""
 
 from . import reflect
-from .ref import Ref, OpRef
+from .ref import MethodSubject, Ref, OpRef
 from .util import *
 
 
@@ -29,15 +29,56 @@ class State(object):
         else:
             return {str(uri(self)): [to_json(form)]}
 
+    def __ns__(self, cxt):
+        form = form_of(self)
+
+        if isinstance(form, OpRef):
+            deanonymize(form, cxt)
+
     def __ref__(self, name):
         return self.__class__(URI(name))
 
     def __repr__(self):
         return f"{self.__class__.__name__}({form_of(self)})"
 
+    def _method(self, name):
+        if isinstance(form_of(self), OpRef):
+            return MethodSubject(self, name)
+
+        subject = uri(self).append(name)
+        if subject.startswith("/state") and subject.path() != uri(self.__class__):
+            raise ValueError(
+                f"cannot call instance method {name} with an absolute path: {subject}")
+
+        return subject
+
+    def _get(self, name, key=None, rtype=None):
+        subject = self._method(name)
+        rtype = State if rtype is None else rtype
+        return rtype(OpRef.Get(subject, key))
+
+    def _put(self, name, key=None, value=None):
+        from .value import Nil
+
+        subject = self._method(name)
+        return Nil(OpRef.Put(subject, key, value))
+
+    def _post(self, _method_name, rtype=None, **params):
+        from .value import Nil
+
+        subject = self._method(_method_name)
+        rtype = State if rtype is None else rtype
+        return rtype(OpRef.Post(subject, **params))
+
+    def _delete(self, name, key=None):
+        from .value import Nil
+
+        subject = self._method(name)
+        return Nil(OpRef.Delete(subject, key))
+
     def dtype(self):
         """Return the native :class:`Class` of this `State`."""
-        return Class(OpRef.get(uri(self) + "/class"))
+        return Class(OpRef.Get(uri(self) + "/class"))
 
 
 class Map(State):
@@ -46,7 +87,7 @@ class Map(State):
     __uri__ = uri(State) + "/map"
 
     def __getitem__(self, key):
-        return OpRef.Get(uri(self), key)
+        return self._get("", key)
 
     def __json__(self):
         return to_json(form_of(self))
@@ -61,7 +102,7 @@ class Tuple(State):
         return to_json(form_of(self))
 
     def __getitem__(self, key):
-        return OpRef.Get(uri(self), key)
+        return self._get("", key)
 
 
 # Scalar types
