@@ -10,6 +10,7 @@ class Context(object):
 
     def __init__(self, context=None):
         object.__setattr__(self, "form", OrderedDict())
+        object.__setattr__(self, "ns", {})
 
         if context:
             if isinstance(context, self.__class__):
@@ -47,12 +48,22 @@ class Context(object):
     def __json__(self):
         return to_json(list(self.form.items()))
 
-    def __setattr__(self, name, value):
+    def __setattr__(self, name, state):
+        deanonymize(state, self)
+
         if name in object.__getattribute__(self, "form"):
             raise ValueError(f"Context already has a value named {name}")
         else:
-            self.form[name] = value
+            self.form[name] = state
+            self.ns[name] = 0
 
+    def generate_name(self, name):
+        if name in self.ns:
+            self.ns[name] += 1
+            return f"{name}_{self.ns[name]}"
+        else:
+            self.ns[name] = 0
+            return name
 
 def form_of(state):
     """Return the form of the given state."""
@@ -97,7 +108,11 @@ class URI(object):
         
         Example:
             `value = OpRef.Get(URI("http://example.com/myapp").append("value_name"))`
-        """ 
+        """
+
+        if not str(name):
+            return self
+
         return URI(str(self), [name])
 
     def host(self):
@@ -147,8 +162,14 @@ class URI(object):
             if i > 0:
                 return self._root[:i]
 
+    def startswith(self, prefix):
+        return str(self).startswith(prefix)
+
     def __add__(self, other):
-        return URI(str(self) + other)
+        if other == "/":
+            return self
+        else:
+            return URI(str(self) + other)
 
     def __radd__(self, other):
         return URI(other) + str(self)
@@ -214,3 +235,14 @@ def to_json(obj):
     else:
         return obj
 
+
+def deanonymize(state, context):
+    if hasattr(state, "__ns__"):
+        state.__ns__(context)
+    elif isinstance(state, tuple) or isinstance(state, list):
+        for item in state:
+            deanonymize(item, context)
+    elif isinstance(state, dict):
+        for key in state:
+            deanonymize(state[key], context)
+
